package loan.origination.result;

import loan.origination.*;
import loan.origination.result.service.LoanOriginationResultClient;
import loan.origination.result.service.LoanOriginationResultRequest;
import loan.origination.result.service.LoanOriginationResultResponse;

public class ResultLauncherLambda {
	
	String endPointURL = "https://lmid2khdc5.execute-api.us-east-1.amazonaws.com/test/loan-origination-result";
	LoanOriginationResultClient client;

	public ResultLauncherLambda() throws Exception {
		client = new LoanOriginationResultClient(endPointURL);
	}
	
	public LoanOriginationResultResponse execute(Application application, Applicant applicant, RequestedProduct requestedProduct, BureauData bureauData) throws Exception {
		try {
			LoanOriginationResultRequest request = new LoanOriginationResultRequest();
	        request.setApplicant(applicant);
	        request.setApplication(application);
	        request.setRequestedProduct(requestedProduct);
	        request.setBureauData(bureauData);
	        LoanOriginationResultResponse response = client.execute(request);
	        String loanOriginationResult = response.getApplication().getLoanOriginationResult();
	        application.setLoanOriginationResult(loanOriginationResult);
	        System.out.println("LoanOriginationResult: " + application.getLoanOriginationResult());
	        return response;
		} catch (Exception e) {
			System.out.println("ERROR executing Lambda: " + endPointURL);
			throw e;
		}
	}
    
    public static void main(String[] args) throws Exception {
        
        
    	ResultLauncherLambda launcher = new ResultLauncherLambda();
        
        Applicant[] applicants = applicantsArray.get();
        Application[] applications = applicationsArray.get();
        RequestedProduct[] requestedProducts = productsArray.get();
        BureauData[] bureauData = bureauDataArray.get();
        
        for (int i = 0; i< applicants.length; i++) {
            System.out.println("\nTest " + i + ": " + applications[i]);
            long startTime = System.currentTimeMillis();
            LoanOriginationResultResponse response = launcher.execute(applications[i],applicants[i],requestedProducts[i],bureauData[i]);
            System.out.println("Response: " + response.getApplication());
            long endTime = System.currentTimeMillis();
            System.out.println("Elapsed time: " + (endTime - startTime +1) + " ms");
        }
    }
 
}
